@@ -18,32 +18,20 @@ extern "C" {
 
 #include <QDebug>
 
-FlatpakReference::FlatpakReference(FlatpakReferencesModel *parent,
-                                   const QString &flatpakName,
+FlatpakReference::FlatpakReference(const QString &flatpakName,
                                    const QString &arch,
                                    const QString &branch,
                                    const QString &version,
                                    const QString &displayName,
-                                   const QUrl &iconSource,
                                    const QStringList &metadataAndOverridesFiles)
-    : QObject(parent)
-    , m_flatpakName(flatpakName)
+    : m_flatpakName(flatpakName)
     , m_arch(arch)
     , m_branch(branch)
     , m_version(version)
     , m_displayName(displayName)
-    , m_iconSource(iconSource)
     , m_metadataAndOverridesFiles(metadataAndOverridesFiles)
     , m_permissionsModel(nullptr)
 {
-    connect(this, &FlatpakReference::needsLoad, parent, &FlatpakReferencesModel::needsLoad);
-    connect(this, &FlatpakReference::settingsChanged, parent, &FlatpakReferencesModel::settingsChanged);
-}
-
-FlatpakReferencesModel *FlatpakReference::parent() const
-{
-    // SAFETY: There's only one constructor, and it always initializes parent with a model object
-    return qobject_cast<FlatpakReferencesModel *>(QObject::parent());
 }
 
 QString FlatpakReference::arch() const
@@ -61,11 +49,6 @@ QString FlatpakReference::version() const
     return m_version;
 }
 
-QUrl FlatpakReference::iconSource() const
-{
-    return m_iconSource;
-}
-
 const QStringList &FlatpakReference::metadataAndOverridesFiles() const
 {
     return m_metadataAndOverridesFiles;
@@ -109,19 +92,7 @@ FlatpakPermissionModel *FlatpakReference::permissionsModel()
 void FlatpakReference::setPermissionsModel(FlatpakPermissionModel *model)
 {
     if (model != m_permissionsModel) {
-        if (m_permissionsModel) {
-            disconnect(m_permissionsModel, &FlatpakPermissionModel::referenceChanged, this, &FlatpakReference::needsLoad);
-            disconnect(m_permissionsModel, &FlatpakPermissionModel::dataChanged, this, &FlatpakReference::settingsChanged);
-            disconnect(m_permissionsModel, &FlatpakPermissionModel::rowsInserted, this, &FlatpakReference::settingsChanged);
-            disconnect(m_permissionsModel, &FlatpakPermissionModel::rowsRemoved, this, &FlatpakReference::settingsChanged);
-        }
         m_permissionsModel = model;
-        if (m_permissionsModel) {
-            connect(m_permissionsModel, &FlatpakPermissionModel::referenceChanged, this, &FlatpakReference::needsLoad);
-            connect(m_permissionsModel, &FlatpakPermissionModel::dataChanged, this, &FlatpakReference::settingsChanged);
-            connect(m_permissionsModel, &FlatpakPermissionModel::rowsInserted, this, &FlatpakReference::settingsChanged);
-            connect(m_permissionsModel, &FlatpakPermissionModel::rowsRemoved, this, &FlatpakReference::settingsChanged);
-        }
     }
 }
 
@@ -187,8 +158,7 @@ static GPtrArray *getUserInstalledFlatpakAppRefs()
     return refs;
 }
 
-FlatpakReferencesModel::FlatpakReferencesModel(QObject *parent)
-    : QAbstractListModel(parent)
+std::vector<std::unique_ptr<FlatpakReference>> FlatpakReference::allFlatpakReferences()
 {
     g_autoptr(GPtrArray) systemInstalledRefs = getSystemInstalledFlatpakAppRefs();
     g_autoptr(GPtrArray) userInstalledRefs = getUserInstalledFlatpakAppRefs();
@@ -196,6 +166,8 @@ FlatpakReferencesModel::FlatpakReferencesModel(QObject *parent)
     const auto systemOverridesDirectory = FlatpakHelper::systemOverridesDirectory();
     const auto userOverridesDirectory = FlatpakHelper::userOverridesDirectory();
 
+    std::vector<std::unique_ptr<FlatpakReference>> references;
+
     for (const auto &refs : {systemInstalledRefs, userInstalledRefs}) {
         for (uint i = 0; i < refs->len; ++i) {
             auto *ref = FLATPAK_REF(g_ptr_array_index(refs, i));
@@ -211,7 +183,6 @@ FlatpakReferencesModel::FlatpakReferencesModel(QObject *parent)
             const auto version = QString::fromUtf8(flatpak_installed_ref_get_appdata_version(iRef));
             const auto displayName = QString::fromUtf8(flatpak_installed_ref_get_appdata_name(iRef));
             const auto appBaseDirectory = QString::fromUtf8(flatpak_installed_ref_get_deploy_dir(iRef));
-            const auto iconSource = FlatpakHelper::iconSourceUrl(displayName, flatpakName, appBaseDirectory);
 
             const auto metadataPath = (refs == systemInstalledRefs) ? FlatpakHelper::metadataPathForSystemInstallation(flatpakName)
                                                                     : FlatpakHelper::metadataPathForUserInstallation(flatpakName);
@@ -230,92 +201,10 @@ FlatpakReferencesModel::FlatpakReferencesModel(QObject *parent)
                 userAppOverrides,
             });
 
-            m_references.push_back(new FlatpakReference(this, flatpakName, arch, branch, version, displayName, iconSource, metadataAndOverridesFiles));
+            references.push_back(std::make_unique<FlatpakReference>(flatpakName, arch, branch, version, displayName, metadataAndOverridesFiles));
         }
     }
-
-    std::ranges::sort(m_references, [](const FlatpakReference *r1, const FlatpakReference *r2) {
-        return r1->displayName() < r2->displayName();
-    });
-}
-
-int FlatpakReferencesModel::rowCount(const QModelIndex &parent) const
-{
-    if (parent.isValid()) {
-        return 0;
-    }
-    return m_references.count();
-}
-
-QVariant FlatpakReferencesModel::data(const QModelIndex &index, int role) const
-{
-    if (!index.isValid()) {
-        return {};
-    }
-
-    switch (Roles(role)) {
-    case Roles::Name:
-        return m_references.at(index.row())->displayName();
-    case Roles::Version:
-        return m_references.at(index.row())->version();
-    case Roles::Icon:
-        return m_references.at(index.row())->iconSource();
-    case Roles::Ref:
-        return QVariant::fromValue<FlatpakReference *>(m_references.at(index.row()));
-    }
-    return {};
-}
-
-QHash<int, QByteArray> FlatpakReferencesModel::roleNames() const
-{
-    QHash<int, QByteArray> roles;
-    roles[Roles::Name] = "name";
-    roles[Roles::Version] = "version";
-    roles[Roles::Icon] = "icon";
-    roles[Roles::Ref] = "ref";
-    return roles;
-}
-
-void FlatpakReferencesModel::load(int index)
-{
-    if (index >= 0 && index < m_references.length()) {
-        m_references.at(index)->load();
-    }
-}
-
-void FlatpakReferencesModel::save(int index)
-{
-    if (index >= 0 && index < m_references.length()) {
-        m_references.at(index)->save();
-    }
-}
-
-void FlatpakReferencesModel::defaults(int index)
-{
-    if (index >= 0 && index < m_references.length()) {
-        m_references.at(index)->defaults();
-    }
-}
-
-bool FlatpakReferencesModel::isSaveNeeded(int index) const
-{
-    if (index >= 0 && index < m_references.length()) {
-        return m_references.at(index)->isSaveNeeded();
-    }
-    return false;
-}
-
-bool FlatpakReferencesModel::isDefaults(int index) const
-{
-    if (index >= 0 && index < m_references.length()) {
-        return m_references.at(index)->isDefaults();
-    }
-    return true;
-}
-
-const QList<FlatpakReference *> &FlatpakReferencesModel::references() const
-{
-    return m_references;
+    return references;
 }
 
 #include "moc_flatpakreference.cpp"
